@@ -53,7 +53,7 @@ class KafkaClient():
             config['sasl.mechanism'] = self.sasl_mechanism
         return config
 
-    def producer_conn(self, produce_to_topic: list[str]=None):
+    def producer_conn(self, produce_to_topic: list=None):
         """Creates the consumer connection to kafka broker
 
         Args:
@@ -68,7 +68,7 @@ class KafkaClient():
         else:
             return None
 
-    def consumer_producer(self, _func=None, *, consumer_from_topic: str, group_id: str, produce_to_topic: list[str]=None):
+    def consumer_producer(self, _func=None, *, consumer_from_topic: str, group_id: str, produce_to_topic: list=None):
         """A method that can be used as decorator to keep consuming data from topics, process this data as per your func and alternatively broadcast the func result to next topic(s)
 
         Args:
